library IEEE;
use IEEE.STD_LOGIC_1164.all;

package config is

constant AMPL_BITS      : natural := 8;           -- AD resolution
constant RAMP_BITS      : natural := 12;          -- DA resolution
constant NUMBCD_BITS    : natural := 16;          -- depend on ramp_bits
--constant WIND_LEN_BITS  : natural := 5;
--constant FIL_NUM        : natural := 2; 
constant MAX_COUNT      : natural := 10000;
constant MAX_FBGS       : natural := 5; 
constant VALVE_RISE     : natural := 10;          -- rises the mean level to discard noise
constant PEAK_UP_THRES  : natural := VALVE_RISE+25;
constant DISPLAY_SAMPLES: natural := 32;          -- how many samples to compute the average value when displaying the peak
constant DISPLAY_BITS   : natural := 5;           -- 2^5=32

constant DA2_BITS       : natural := 16;          -- number of bits sent to the converted by serial line
constant DA2COUNT       : natural := 12;          -- clock divisor (SCLK)
constant DA2CLOCK       : natural := DA2COUNT / 2;-- to control the rising and faling edge of SCLK

constant DVSR           : natural := 54;          -- 100mhz / (115200hz*16)
constant DVSR_BIT       : natural := 6;           -- 2^6 > 54

constant NCOEF          : natural := 31;           -- number of FIR filter coefficients
constant COEF_BITS      : natural := 18;           -- number of bits of each coefficient
constant MUL_BITS       : natural := AMPL_BITS+COEF_BITS+1;   -- signed!
constant OUT_BITS       : natural := AMPL_BITS+8;  -- adds more bits to enhance resolution
constant TOTAL_BITS     : natural := 5+AMPL_BITS+COEF_BITS+1; -- log2(NCOEF)+AMPL_BITS+COEF_BITS+1
constant NLAT           : natural := (NCOEF-1)/2+3;   -- FIR filter latency (NOT SURE!)

end config;

package body config is 
end config;
