---------------------------------------------------------------------------------- 
-- create date:    16:23:46 06/11/2012 
-- module name:    filter_mul - behavioral 
----------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use work.config.all;

entity filter_mul is
    port (
        clk      : in  std_logic;
        reset    : in  std_logic;
        syn_tick : in  std_logic; 
        din      : in  signed (AMPL_BITS    downto 0);
        coef     : in  signed (COEF_BITS-1  downto 0); 
		dout1    : out signed (MUL_BITS-1  downto 0); 
		dout2    : out signed (MUL_BITS-1  downto 0)
    );
end filter_mul;

architecture behavioral of filter_mul is
    signal dinr    : signed(din'range);
    signal coefr   : signed(coef'range);    
    signal mult    : signed(MUL_BITS - 1 downto 0);
begin

process(clk)  begin
    if rising_edge(clk)  then
        if reset = '1' then
            dout1 <= (others => '0');
            dout2 <= (others => '0');
            mult  <= (others => '0');
            dinr  <= (others => '0');
            coefr <= (others => '0');
        else
            if (syn_tick = '1') then
                dinr  <= din;
                coefr <= coef;
                mult  <= dinr * coefr;
				dout1 <= mult; 
				dout2 <= mult;
            end if; 
        end if;
	end if;
end process;

end behavioral;