library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity restoring is
    generic (
        num_bits : natural := 24;
        den_bits : natural := 16;
        quot_bits: natural := 8
    );
    port (
        clk         : in  std_logic;
        reset       : in  std_logic;
        numerator   : in  unsigned (num_bits-1 downto 0);
        denumerator : in  unsigned (den_bits-1 downto 0);
        restart     : in  std_logic;
        quotient    : out unsigned (quot_bits-1 downto 0);
        div_done    : out std_logic
    );
end restoring;

architecture Behavioral of restoring is
    signal done: std_logic := '0';
begin

process(clk, restart, numerator, denumerator)
    variable pr : unsigned(num_bits-1 downto 0); 
    variable dd : unsigned(num_bits-1 downto 0); 
    variable it : natural range 0 to num_bits;
begin
    if rising_edge(clk) then
        if reset = '1' or restart = '1' then
            it := 0;
            pr := (others => '0');
            dd := numerator;
            done <= '0';
        end if;
          
        if done = '0' then
            if it < num_bits then
                pr := pr(num_bits-2 downto 0) & dd(num_bits-1);
                dd := dd(num_bits-2 downto 0) & '0';
            
                if denumerator <= pr then
                    pr := pr - denumerator;
                    dd(0) := '1';
                end if;
            
                it := it + 1;
            end if;
        
            if it = num_bits then
                done      <= '1';
                quotient  <= dd(quot_bits-1 downto 0);
            end if;
        end if;
    end if;
end process;

div_done <= done;

end Behavioral;
